<?php

namespace app\admin\controller;

use app\admin\logic\GoodGroupLogic;
use app\BaseController;
use app\model\CommonModel;
use think\exception\ValidateException;
use think\facade\Config;
use think\facade\Validate;

//【商品分组】
class GoodGroup extends BaseController
{
    //获取商品分组列表
    public function list()
    {
        $param = $this->request->only(['page' => 1, 'size' => 10, 'status' => '', 'company_title' => '', 'card_title' => ''], 'post');

        return GoodGroupLogic::list($param);
    }

    //添加商品分组
    public function add()
    {
        $param = $this->request->only(['company_id', 'card_id', 'remark' => ''], 'post');

        $val = Validate::rule(Config::get('validate_rules.GoodGroupAdd'));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return GoodGroupLogic::add($param);
    }

    //获取商品分组详情
    public function read()
    {
        $id = $this->request->post('id/d', 0);
        return GoodGroupLogic::read($id);
    }

    //编辑商品分组
    public function edit()
    {
        $param = $this->request->only(['id', 'company_id', 'card_id', 'remark' => ''], 'post');

        $val = Validate::rule(array_merge(Config::get('validate_rules.GoodGroupAdd'), ['id|商品分组id' => 'require|number|gt:0']));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return GoodGroupLogic::edit($param);
    }

    //商品分组启禁用
    public function status()
    {
        $param = $this->request->only(['id', 'status'], 'post');

        $val = Validate::rule(Config::get('validate_rules.status'));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return GoodGroupLogic::status($param);
    }

    //删除商品分组
    public function delete()
    {
        $ids = $this->request->post('id/a', []);
        return GoodGroupLogic::delete($ids);
    }


}